@@ -8,7 +8,7 @@ use English;
 use Error::Pure qw(err);
 use List::Util qw(none);
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 sub new {
 	my ($class, @params) = @_;
@@ -16,6 +16,9 @@ sub new {
 	# Create object.
 	my $self = bless {}, $class;
 
+	# db debug.
+	$self->{'db_debug'} = 0;
+
 	# db user password.
 	$self->{'db_password'} = undef;
 
@@ -50,8 +53,8 @@ sub new {
 	$self->{'_schema'} = eval {
 		$self->{'schema_module'}->connect(
 			$self->{'dsn'},
-			$self->{'user'},
-			$self->{'password'},
+			$self->{'db_user'},
+			$self->{'db_password'},
 			$self->{'db_options'},
 		);
 	};
@@ -66,6 +69,10 @@ sub new {
 		;
 	}
 
+	if ($self->{'db_debug'}) {
+		$self->{'_schema'}->storage->debug(1);
+	}
+
 	return $self;
 }
 
